=== modified file '__init__.py'
--- __init__.py	2017-12-23 13:55:23 +0000
+++ __init__.py	2017-12-23 14:51:04 +0000
@@ -112,8 +112,8 @@
 
     commands.register_command(cmd_load_test_loggerhead)
 
-    def load_tests(standard_tests, module, loader):
+    def load_tests(loader, basic_tests, pattern):
         _ensure_loggerhead_path()
-        standard_tests.addTests(loader.loadTestsFromModuleNames(
-            ['breezy.plugins.loggerhead.loggerhead.tests']))
-        return standard_tests
+        basic_tests.addTest(loader.loadTestsFromModuleNames(
+            ['%s.loggerhead.tests' % __name__]))
+        return basic_tests

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2017-10-14 14:33:57 +0000
+++ loggerhead/__init__.py	2017-12-23 14:51:04 +0000
@@ -32,12 +32,3 @@
 except pkg_resources.DistributionNotFound:
     # No paste.deploy is OK, but an old paste.deploy is bad.
     pass
-
-try:
-    from breezy.branch import Branch
-    branch = Branch.open('./');
-
-    __revision__ = branch.revno()
-    
-except:
-    pass

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2012-02-08 01:50:02 +0000
+++ loggerhead/controllers/annotate_ui.py	2017-12-23 14:51:04 +0000
@@ -26,6 +26,7 @@
     def annotate_file(self, info):
         file_id = info['file_id']
         revid = info['change'].revid
+        path = self._history.get_path(revid, file_id)
         
         tree = self.tree_for(file_id, revid)
         
@@ -37,7 +38,7 @@
         revisions = {}
 
         lineno = 0
-        for (line_revid, text), lineno in zip(tree.annotate_iter(file_id), itertools.count(1)):
+        for (line_revid, text), lineno in zip(tree.annotate_iter(path, file_id), itertools.count(1)):
             if line_revid != last_line_revid:
                 last_line_revid = line_revid
 

=== modified file 'loggerhead/controllers/view_ui.py'
--- loggerhead/controllers/view_ui.py	2017-10-14 14:33:57 +0000
+++ loggerhead/controllers/view_ui.py	2017-12-23 14:51:04 +0000
@@ -47,14 +47,16 @@
     template_path = 'loggerhead.templates.view'
     
     def tree_for(self, file_id, revid):
-        file_revid = self._history.get_inventory(revid)[file_id].revision
+        rev_tree = self._history.revision_tree(revid)
+        file_revid = rev_tree.get_file_revision(rev_tree.id2path(file_id), file_id)
         return self._history._branch.repository.revision_tree(file_revid)
 
     def text_lines(self, file_id, revid):
-        file_name = os.path.basename(self._history.get_path(revid, file_id))
+        path = self._history.get_path(revid, file_id)
+        file_name = os.path.basename(path)
         
         tree = self.tree_for(file_id, revid)
-        file_text = tree.get_file_text(file_id)
+        file_text = tree.get_file_text(path, file_id)
         encoding = 'utf-8'
         try:
             file_text = file_text.decode(encoding)
@@ -119,20 +121,15 @@
                 self._branch.is_root,
                 'files'))
 
+        tree = history.revision_tree(revid)
+
         # Create breadcrumb trail for the path within the branch
-        try:
-            inv = history.get_inventory(revid)
-        except:
-            self.log.exception('Exception fetching changes')
-            raise HTTPServerError('Could not fetch changes')
-        branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
+        branch_breadcrumbs = util.branch_breadcrumbs(path, tree, 'files')
 
-        try:
-            file = inv[file_id]
-        except NoSuchId:
+        if not tree.has_id(file_id):
             raise HTTPNotFound()
 
-        if file.kind == "directory":
+        if tree.kind(path, file_id) == "directory":
             raise HTTPMovedPermanently(self._branch.context_url(['/files', revno_url, path]))
 
         # no navbar for revisions

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2017-12-23 13:55:15 +0000
+++ loggerhead/history.py	2017-12-23 14:51:04 +0000
@@ -40,6 +40,7 @@
 import breezy.delta
 import breezy.errors
 import breezy.foreign
+import breezy.osutils
 import breezy.revision
 
 from loggerhead import search
@@ -565,16 +566,13 @@
             # search index.
             return None, None, []
 
-    def get_inventory(self, revid):
-        if revid not in self._inventory_cache:
-            self._inventory_cache[revid] = (
-                self._branch.repository.get_inventory(revid))
-        return self._inventory_cache[revid]
+    def revision_tree(self, revid):
+        return self._branch.repository.revision_tree(revid)
 
     def get_path(self, revid, file_id):
         if (file_id is None) or (file_id == ''):
             return ''
-        path = self.get_inventory(revid).id2path(file_id)
+        path = self.revision_tree(revid).id2path(file_id)
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
         return path
@@ -582,7 +580,7 @@
     def get_file_id(self, revid, path):
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
-        return self.get_inventory(revid).path2id(path)
+        return self.revision_tree(revid).path2id(path)
 
     def get_merge_point_list(self, revid):
         """
@@ -754,13 +752,12 @@
 
     def get_file(self, file_id, revid):
         """Returns (path, filename, file contents)"""
-        inv = self.get_inventory(revid)
-        inv_entry = inv[file_id]
-        rev_tree = self._branch.repository.revision_tree(inv_entry.revision)
-        path = inv.id2path(file_id)
-        if not path.startswith('/'):
+        rev_tree = self._branch.repository.revision_tree(revid)
+        path = rev_tree.id2path(file_id)
+        display_path = path
+        if not display_path.startswith('/'):
             path = '/' + path
-        return path, inv_entry.name, rev_tree.get_file_text(file_id)
+        return display_path, breezy.osutils.basename(path), rev_tree.get_file_text(path, file_id)
 
     def file_changes_for_revision_ids(self, old_revid, new_revid):
         """

=== modified file 'loggerhead/tests/__init__.py'
--- loggerhead/tests/__init__.py	2011-09-08 00:33:28 +0000
+++ loggerhead/tests/__init__.py	2017-12-23 14:51:04 +0000
@@ -15,8 +15,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-def load_tests(standard_tests, module, loader):
-    standard_tests.addTests(loader.loadTestsFromModuleNames([
+def load_tests(loader, basic_tests, pattern):
+    basic_tests.addTests(loader.loadTestsFromModuleNames([
         (__name__ + '.' + x) for x in [
             'test_controllers',
             'test_corners',
@@ -28,4 +28,4 @@
             'test_templating',
             'test_util',
         ]]))
-    return standard_tests
+    return basic_tests

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2016-09-04 15:13:21 +0000
+++ loggerhead/tests/test_controllers.py	2017-12-23 14:51:04 +0000
@@ -55,8 +55,8 @@
     def test_get_filelist(self):
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
             ['filename'])
-        inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
-        self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename', 'head')))
+        revtree = bzrbranch.repository.revision_tree(bzrbranch.last_revision())
+        self.assertEqual(1, len(inv_ui.get_filelist(revtree, '', 'filename', 'head')))
 
     def test_smoke(self):
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
@@ -223,21 +223,21 @@
     def make_branch_app_for_filediff_ui(self):
         builder = self.make_branch_builder('branch')
         builder.start_series()
-        builder.build_snapshot('rev-1-id', None, [
+        rev1 = builder.build_snapshot(None, [
             ('add', ('', 'root-id', 'directory', '')),
             ('add', ('filename', 'f-id', 'file', 'content\n'))],
             message="First commit.")
-        builder.build_snapshot('rev-2-id', None, [
-            ('modify', ('f-id', 'new content\n'))])
+        rev2 = builder.build_snapshot(None, [
+             ('modify', ('f-id', 'new content\n'))])
         builder.finish_series()
         branch = builder.get_branch()
         self.addCleanup(branch.lock_read().unlock)
-        return self.make_branch_app(branch)
+        return self.make_branch_app(branch), (rev1, rev2)
 
     def test_get_values_smoke(self):
-        branch_app = self.make_branch_app_for_filediff_ui()
+        branch_app, (rev1, rev2) = self.make_branch_app_for_filediff_ui()
         env = {'SCRIPT_NAME': '/',
-               'PATH_INFO': '/+filediff/rev-2-id/rev-1-id/f-id',
+               'PATH_INFO': '/+filediff/%s/%s/f-id' % (rev2, rev1),
                'REQUEST_METHOD': 'GET'}
         filediff_ui = branch_app.lookup_app(env)
         filediff_ui.parse_args(env)
@@ -247,9 +247,9 @@
         self.assertEqual('new content', chunks[0].diff[1].line)
 
     def test_json_render_smoke(self):
-        branch_app = self.make_branch_app_for_filediff_ui()
+        branch_app, (rev1, rev2) = self.make_branch_app_for_filediff_ui()
         env = {'SCRIPT_NAME': '/',
-               'PATH_INFO': '/+json/+filediff/rev-2-id/rev-1-id/f-id',
+               'PATH_INFO': '/+json/+filediff/%s/%s/f-id' % (rev2, rev1),
                'REQUEST_METHOD': 'GET'}
         filediff_ui = branch_app.lookup_app(env)
         self.assertOkJsonResponse(filediff_ui, env)
@@ -260,19 +260,19 @@
     def make_branch_app_for_revlog_ui(self):
         builder = self.make_branch_builder('branch')
         builder.start_series()
-        builder.build_snapshot('rev-id', None, [
+        revid = builder.build_snapshot(None, [
             ('add', ('', 'root-id', 'directory', '')),
             ('add', ('filename', 'f-id', 'file', 'content\n'))],
             message="First commit.")
         builder.finish_series()
         branch = builder.get_branch()
         self.addCleanup(branch.lock_read().unlock)
-        return self.make_branch_app(branch)
+        return self.make_branch_app(branch), revid
 
     def test_get_values_smoke(self):
-        branch_app = self.make_branch_app_for_revlog_ui()
+        branch_app, revid = self.make_branch_app_for_revlog_ui()
         env = {'SCRIPT_NAME': '/',
-               'PATH_INFO': '/+revlog/rev-id',
+               'PATH_INFO': '/+revlog/%s' % revid,
                'REQUEST_METHOD': 'GET'}
         revlog_ui = branch_app.lookup_app(env)
         revlog_ui.parse_args(env)
@@ -281,8 +281,8 @@
         self.assertEqual(values['entry'].comment, "First commit.")
 
     def test_json_render_smoke(self):
-        branch_app = self.make_branch_app_for_revlog_ui()
-        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/+json/+revlog/rev-id',
+        branch_app, revid = self.make_branch_app_for_revlog_ui()
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/+json/+revlog/%s' % revid,
                'REQUEST_METHOD': 'GET'}
         revlog_ui = branch_app.lookup_app(env)
         self.assertOkJsonResponse(revlog_ui, env)

=== modified file 'loggerhead/tests/test_history.py'
--- loggerhead/tests/test_history.py	2017-10-14 14:33:57 +0000
+++ loggerhead/tests/test_history.py	2017-12-23 14:51:04 +0000
@@ -40,26 +40,27 @@
         # rev-1
         builder = self.make_branch_builder('branch')
         builder.start_series()
-        builder.build_snapshot('rev-1', None, [
+        rev1 = builder.build_snapshot(None, [
             ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('rev-2', ['rev-1'], [])
-        builder.build_snapshot('rev-3', ['rev-2'], [])
+        rev2 = builder.build_snapshot([rev1], [])
+        rev3 = builder.build_snapshot([rev2], [])
         builder.finish_series()
         b = builder.get_branch()
         self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
+        return _mod_history.History(b, {}), [rev1, rev2, rev3]
 
     def make_long_linear_ancestry(self):
         builder = self.make_branch_builder('branch')
+        revs = []
         builder.start_series()
-        builder.build_snapshot('A', None, [
-            ('add', ('', 'root-id', 'directory', None))])
+        revs.append(builder.build_snapshot(None, [
+            ('add', ('', 'root-id', 'directory', None))]))
         for r in "BCDEFGHIJKLMNOPQRSTUVWXYZ":
-            builder.build_snapshot(r, None, [])
+            revs.append(builder.build_snapshot(None, []))
         builder.finish_series()
         b = builder.get_branch()
         self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
+        return _mod_history.History(b, {}), revs
 
     def make_merged_ancestry(self):
         # Time goes up
@@ -70,14 +71,14 @@
         # rev-1
         builder = self.make_branch_builder('branch')
         builder.start_series()
-        builder.build_snapshot('rev-1', None, [
+        rev1 = builder.build_snapshot(None, [
             ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('rev-2', ['rev-1'], [])
-        builder.build_snapshot('rev-3', ['rev-1', 'rev-2'], [])
+        rev2 = builder.build_snapshot([rev1], [])
+        rev3 = builder.build_snapshot([rev1, rev2], [])
         builder.finish_series()
         b = builder.get_branch()
         self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
+        return _mod_history.History(b, {}), [rev1, rev2, rev3]
 
     def make_deep_merged_ancestry(self):
         # Time goes up
@@ -92,17 +93,18 @@
         # A
         builder = self.make_branch_builder('branch')
         builder.start_series()
-        builder.build_snapshot('A', None, [
+        rev_a = builder.build_snapshot(None, [
             ('add', ('', 'root-id', 'directory', None))])
-        builder.build_snapshot('B', ['A'], [])
-        builder.build_snapshot('C', ['A'], [])
-        builder.build_snapshot('D', ['C'], [])
-        builder.build_snapshot('E', ['C', 'D'], [])
-        builder.build_snapshot('F', ['B', 'E'], [])
+        rev_b = builder.build_snapshot([rev_a], [])
+        rev_c = builder.build_snapshot([rev_a], [])
+        rev_d = builder.build_snapshot([rev_c], [])
+        rev_e = builder.build_snapshot([rev_c, rev_d], [])
+        rev_f = builder.build_snapshot([rev_b, rev_e], [])
         builder.finish_series()
         b = builder.get_branch()
         self.addCleanup(b.lock_read().unlock)
-        return _mod_history.History(b, {})
+        return (_mod_history.History(b, {}),
+                [rev_a, rev_b, rev_c, rev_d, rev_e, rev_f])
 
     def assertRevidsFrom(self, expected, history, search_revs, tip_rev):
         self.assertEqual(expected,
@@ -136,59 +138,58 @@
 class TestHistoryGetRevidsFrom(TestCaseWithExamples):
 
     def test_get_revids_from_simple_mainline(self):
-        history = self.make_linear_ancestry()
-        self.assertRevidsFrom(['rev-3', 'rev-2', 'rev-1'],
-                              history, None, 'rev-3')
+        history, revs = self.make_linear_ancestry()
+        self.assertRevidsFrom(list(reversed(revs)), history, None, revs[2])
 
     def test_get_revids_from_merged_mainline(self):
-        history = self.make_merged_ancestry()
-        self.assertRevidsFrom(['rev-3', 'rev-1'],
-                              history, None, 'rev-3')
+        history, revs = self.make_merged_ancestry()
+        self.assertRevidsFrom([revs[2], revs[0]],
+                              history, None, revs[2])
 
     def test_get_revids_given_one_rev(self):
-        history = self.make_merged_ancestry()
+        history, revs = self.make_merged_ancestry()
         # rev-3 was the first mainline revision to see rev-2.
-        self.assertRevidsFrom(['rev-3'], history, ['rev-2'], 'rev-3')
+        self.assertRevidsFrom([revs[2]], history, [revs[1]], revs[2])
 
     def test_get_revids_deep_ancestry(self):
-        history = self.make_deep_merged_ancestry()
-        self.assertRevidsFrom(['F'], history, ['F'], 'F')
-        self.assertRevidsFrom(['F'], history, ['E'], 'F')
-        self.assertRevidsFrom(['F'], history, ['D'], 'F')
-        self.assertRevidsFrom(['F'], history, ['C'], 'F')
-        self.assertRevidsFrom(['B'], history, ['B'], 'F')
-        self.assertRevidsFrom(['A'], history, ['A'], 'F')
+        history, revs = self.make_deep_merged_ancestry()
+        self.assertRevidsFrom([revs[-1]], history, [revs[-1]], revs[-1])
+        self.assertRevidsFrom([revs[-1]], history, [revs[-2]], revs[-1])
+        self.assertRevidsFrom([revs[-1]], history, [revs[-3]], revs[-1])
+        self.assertRevidsFrom([revs[-1]], history, [revs[-4]], revs[-1])
+        self.assertRevidsFrom([revs[1]], history, [revs[-5]], revs[-1])
+        self.assertRevidsFrom([revs[0]], history, [revs[-6]], revs[-1])
 
     def test_get_revids_doesnt_over_produce_simple_mainline(self):
         # get_revids_from shouldn't walk the whole ancestry just to get the
         # answers for the first few revisions.
-        history = self.make_long_linear_ancestry()
+        history, revs = self.make_long_linear_ancestry()
         accessed = track_rev_info_accesses(history)
-        result = history.get_revids_from(None, 'Z')
-        self.assertEqual(set(), accessed)
-        self.assertEqual('Z', result.next())
-        # We already know 'Z' because we passed it in.
-        self.assertEqual(set(), accessed)
-        self.assertEqual('Y', result.next())
-        self.assertEqual(set([history._rev_indices['Z']]), accessed)
+        result = history.get_revids_from(None, revs[-1])
+        self.assertEqual(set(), accessed)
+        self.assertEqual(revs[-1], result.next())
+        # We already know revs[-1] because we passed it in.
+        self.assertEqual(set(), accessed)
+        self.assertEqual(revs[-2], result.next())
+        self.assertEqual(set([history._rev_indices[revs[-1]]]), accessed)
 
     def test_get_revids_doesnt_over_produce_for_merges(self):
         # get_revids_from shouldn't walk the whole ancestry just to get the
         # answers for the first few revisions.
-        history = self.make_long_linear_ancestry()
+        history, revs = self.make_long_linear_ancestry()
         accessed = track_rev_info_accesses(history)
-        result = history.get_revids_from(['X', 'V'], 'Z')
+        result = history.get_revids_from([revs[-3], revs[-5]], revs[-1])
         self.assertEqual(set(), accessed)
-        self.assertEqual('X', result.next())
+        self.assertEqual(revs[-3], result.next())
         # We access 'W' because we are checking that W wasn't merged into X.
         # The important bit is that we aren't getting the whole ancestry.
-        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXW']),
+        self.assertEqual(set([history._rev_indices[x] for x in list(reversed(revs))[:4]]),
                          accessed)
-        self.assertEqual('V', result.next())
-        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+        self.assertEqual(revs[-5], result.next())
+        self.assertEqual(set([history._rev_indices[x] for x in list(reversed(revs))[:6]]),
                          accessed)
         self.assertRaises(StopIteration, result.next)
-        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+        self.assertEqual(set([history._rev_indices[x] for x in list(reversed(revs))[:6]]),
                          accessed)
 
 
@@ -291,32 +292,32 @@
     def test_get_view_limited_history(self):
         # get_view should only load enough history to serve the result, not all
         # history.
-        history = self.make_long_linear_ancestry()
+        history, revs = self.make_long_linear_ancestry()
         accessed = track_rev_info_accesses(history)
-        revid, start_revid, revid_list = history.get_view('Z', 'Z', None,
+        revid, start_revid, revid_list = history.get_view(revs[-1], revs[-1], None,
                                                       extra_rev_count=5)
-        self.assertEqual(['Z', 'Y', 'X', 'W', 'V', 'U'], revid_list)
-        self.assertEqual('Z', revid)
-        self.assertEqual('Z', start_revid)
-        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+        self.assertEqual(list(reversed(revs))[:6], revid_list)
+        self.assertEqual(revs[-1], revid)
+        self.assertEqual(revs[-1], start_revid)
+        self.assertEqual(set([history._rev_indices[x] for x in list(reversed(revs))[:6]]),
                          accessed)
 
 
 class TestHistoryGetChangedUncached(TestCaseWithExamples):
 
     def test_native(self):
-        history = self.make_linear_ancestry()
-        changes = history.get_changes_uncached(['rev-1', 'rev-2'])
+        history, revs = self.make_linear_ancestry()
+        changes = history.get_changes_uncached([revs[0], revs[1]])
         self.assertEquals(2, len(changes))
-        self.assertEquals('rev-1', changes[0].revid)
-        self.assertEquals('rev-2', changes[1].revid)
+        self.assertEquals(revs[0], changes[0].revid)
+        self.assertEquals(revs[1], changes[1].revid)
         self.assertIs(None, getattr(changes[0], 'foreign_vcs', None))
         self.assertIs(None, getattr(changes[0], 'foreign_revid', None))
 
     def test_foreign(self):
         # Test with a mocked foreign revision, as it's not possible
         # to rely on any foreign plugins being installed.
-        history = self.make_linear_ancestry()
+        history, revs = self.make_linear_ancestry()
         foreign_vcs = ForeignVcs(None, "vcs")
         foreign_vcs.show_foreign_revid = repr
         foreign_rev = ForeignRevision(("uuid", 1234), VcsMapping(foreign_vcs),

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2017-10-14 14:33:57 +0000
+++ loggerhead/util.py	2017-12-23 14:51:04 +0000
@@ -456,7 +456,7 @@
     return breadcrumbs
 
 
-def branch_breadcrumbs(path, inv, view):
+def branch_breadcrumbs(path, tree, view):
     """
     Generate breadcrumb information from the branch path given
 
@@ -464,7 +464,7 @@
 
     Arguments:
     path -- The path to convert into breadcrumbs
-    inv -- Inventory to get file information from
+    tree -- Tree to get file information from
     view -- The type of view we are showing (files, changes etc)
     """
     dir_parts = path.strip('/').split('/')

